@@ -10,19 +10,19 @@
 //  W A R N I N G
 //  -------------
 //
-// This file is not part of the KDecoration2 API.  It exists purely as an
+// This file is not part of the KDecoration3 API.  It exists purely as an
 // implementation detail.  This header file may change from version to
 // version without notice, or even be removed.
 //
 // We mean it.
 //
 
-namespace KDecoration2
+namespace KDecoration3
 {
 class Decoration;
 class DecorationBridge;
 class DecorationButton;
-class DecoratedClient;
+class DecoratedWindow;
 class DecorationSettings;
 class DecorationShadow;
 
@@ -31,24 +31,25 @@ class Q_DECL_HIDDEN Decoration::Private
 public:
     Private(Decoration *decoration, const QVariantList &args);
 
-    QMargins borders;
-    QMargins resizeOnlyBorders;
+    QMarginsF resizeOnlyBorders;
 
     Qt::WindowFrameSection sectionUnderMouse;
     void setSectionUnderMouse(Qt::WindowFrameSection section);
     void updateSectionUnderMouse(const QPoint &mousePosition);
 
-    QRect titleBar;
+    QRectF titleBar;
     QRegion blurRegion;
 
     void addButton(DecorationButton *button);
 
     std::shared_ptr<DecorationSettings> settings;
     DecorationBridge *bridge;
-    std::shared_ptr<DecoratedClient> client;
+    std::shared_ptr<DecoratedWindow> client;
     bool opaque;
     QList<DecorationButton *> buttons;
     std::shared_ptr<DecorationShadow> shadow;
+    std::shared_ptr<DecorationState> next;
+    std::shared_ptr<DecorationState> current;
 
 private:
     Decoration *q;
