@@ -1,37 +1,20 @@
 /*
- * Copyright 2014  Martin Gräßlin <mgraesslin@kde.org>
+ * SPDX-FileCopyrightText: 2014 Martin Gräßlin <mgraesslin@kde.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
-#ifndef KDECORATION2_DECORATION_DEFINES_H
-#define KDECORATION2_DECORATION_DEFINES_H
+#pragma once
 
-namespace KDecoration2
+namespace KDecoration3
 {
-
 /**
  * The DecorationButtonType is a helper type for the DecorationButton.
  * A Decoration should provide a DecorationButton for each of the types,
  * if it wants to provide further buttons it should use the Custom type.
  * The DecorationButton gets configured depending on the type. E.g. the
- * Close button gets disabled if the DecoratedClient is not closeable.
+ * Close button gets disabled if the DecoratedWindow is not closeable.
  **/
-enum class DecorationButtonType
-{
+enum class DecorationButtonType {
     /**
      * The Menu button requests showing the window menu on left or right click.
      **/
@@ -41,53 +24,56 @@ enum class DecorationButtonType
      */
     ApplicationMenu,
     /**
-     * The OnAllDesktops button requests toggling the DecoratedClient's on all desktops state.
+     * The OnAllDesktops button requests toggling the DecoratedWindow's on all desktops state.
      * The DecoratedButton is only visible if multiple virtual desktops are available.
      **/
     OnAllDesktops,
     /**
-     * The Minimize button requests minimizing the DecoratedClient. The DecorationButton is only
-     * enabled if the DecoratedClient is minimizeable.
+     * The Minimize button requests minimizing the DecoratedWindow. The DecorationButton is only
+     * enabled if the DecoratedWindow is minimizeable.
      **/
     Minimize,
     /**
-     * The Maximize button requests maximizing the DecoratedClient. The DecorationButton is checkable
-     * and if the DecoratedClient is maximized the DecorationButton is checked. The DecorationButton
+     * The Maximize button requests maximizing the DecoratedWindow. The DecorationButton is checkable
+     * and if the DecoratedWindow is maximized the DecorationButton is checked. The DecorationButton
      * supports multiple mouse buttons to change horizontal, vertical and overall maximized state.
      *
-     * The DecorationButton is only enabled if the DecoratedClient is maximizeable.
+     * The DecorationButton is only enabled if the DecoratedWindow is maximizeable.
      **/
     Maximize,
     /**
-     * The Close button requests closing the DecoratedClient. The DecorationButton is only enabled
-     * if the DecoratedClient is closeable.
+     * The Close button requests closing the DecoratedWindow. The DecorationButton is only enabled
+     * if the DecoratedWindow is closeable.
      **/
     Close,
     /**
      * The ContextHelp button requests entering the context help mode. The DecorationButton is only
-     * visible if the DecoratedClient provides context help.
+     * visible if the DecoratedWindow provides context help.
      **/
     ContextHelp,
     /**
-     * The Shade button requests toggling the DecoratedClient's shaded state. The DecoratedButton
-     * is only enabled if the DecoratedClient is shadeable.
+     * The Shade button requests toggling the DecoratedWindow's shaded state. The DecoratedButton
+     * is only enabled if the DecoratedWindow is shadeable.
      **/
     Shade,
     /**
-     * The KeepBelow button requests toggling the DecoratedClient's keep below state.
+     * The KeepBelow button requests toggling the DecoratedWindow's keep below state.
      **/
     KeepBelow,
     /**
-     * The KeepAbove button requests toggling the DecoratedClient's keep above state.
+     * The KeepAbove button requests toggling the DecoratedWindow's keep above state.
      **/
     KeepAbove,
     /**
      * The Custom type allows a Decoration to provide custom DecorationButtons.
      **/
-    Custom
+    Custom,
+    /**
+     * The Spacer button provides some space between buttons.
+     */
+    Spacer,
 };
 
-
 /**
  * Border sizes are a combination of visual and accessibility features.
  * Larger borders should be used to increase the non title bar borders to
@@ -132,11 +118,11 @@ enum class BorderSize {
     /**
      * Increased border sizes, considered a factor of 5.0.
      **/
-    Oversized
+    Oversized,
 };
 
 /**
- * Color groups are used for DecoratedClient::color().
+ * Color groups are used for DecoratedWindow::color().
  * @since 5.3
  **/
 enum class ColorGroup {
@@ -152,11 +138,11 @@ enum class ColorGroup {
      * Warning color, can only be used with ColorRole::Foreground. If used with other roles,
      * a invalid QColor is returned. It can be used for close buttons and is typically red.
      **/
-    Warning
+    Warning,
 };
 
 /**
- * Color roles are used for DecoratedClient::color().
+ * Color roles are used for DecoratedWindow::color().
  * @since 5.3
  **/
 enum class ColorRole {
@@ -171,9 +157,7 @@ enum class ColorRole {
     /**
      * The decoration's title bar forground color
      **/
-    Foreground
+    Foreground,
 };
 
 }
-
-#endif
